@@ -6,7 +6,6 @@ import json
 import logging
 import os
 from functools import wraps
-from typing import Optional
 
 from flask import Response, jsonify, request
 
@@ -44,7 +43,7 @@ assert set(dobot_model_mapping.keys()) == DobotModels.set()
 
 app = create_app(__name__)
 
-_dobot: Optional[Dobot] = None
+_dobot: None | Dobot = None
 _mock = False
 
 
@@ -344,7 +343,7 @@ def put_eef_pose() -> RespT:
         raise DobotGeneral("Body should be a JSON dict containing Pose.")
 
     pose = Pose.from_dict(request.json)
-    move_type = MoveType(request.args.get("moveType", "jump"))
+    move_type = MoveType(request.args.get("moveType", MoveType.JUMP))
     velocity = float(request.args.get("velocity", default=50.0))
     acceleration = float(request.args.get("acceleration", default=50.0))
     safe = request.args.get("safe") == "true"
@@ -628,21 +627,6 @@ def handle_dobot_exception(e: DobotApiException) -> tuple[str, int]:
     return json.dumps(DobotGeneral(str(e)).to_dict()), 500
 
 
-@app.route("/health")
-def health():
-    """Healthcheck.
-    ---
-    get:
-        tags:
-            - Service
-        description: Gets service health status.
-        responses:
-            204:
-              description: The service is up and running.
-    """
-    return Response(status=204)
-
-
 def main() -> None:
 
     parser = argparse.ArgumentParser(description=SERVICE_NAME)
@@ -676,7 +660,7 @@ def main() -> None:
         port_from_url(URL),
         [Pose, Joint, WebApiError],
         args.swagger,
-        dependencies={"ARCOR2 Scene": "0.1.0"},
+        dependencies={"ARCOR2 Scene": "1.0.0"},
     )
 
     if _dobot:
